@@ -1,4 +1,4 @@
-# $Id: thingspeak.py 1161 2014-12-05 21:11:50Z mwall $
+# $Id: thingspeak.py 1296 2015-03-23 21:50:44Z mwall $
 # Copyright 2013-2014 Matthew Wall
 
 """
@@ -43,7 +43,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.2"
+VERSION = "0.4"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -139,27 +139,20 @@ class ThingSpeak(weewx.restx.StdRESTbase):
             logerr("Data will not be uploaded: Missing option %s" % e)
             return
 
-        errs = []
+        site_dict.setdefault('augment_record', True)
+
         usn = site_dict.get('unit_system', None)
         if usn is not None:
-            if usn in weewx.units.unit_constants:
-                site_dict['unit_system'] = weewx.units.unit_constants[usn]
-            else:
-                errs.append("unknown unit_system %s" % usn)
+            site_dict['unit_system'] = weewx.units.unit_constants[usn]
 
-        if errs:
-            for msg in errs:
-                logerr(msg)
-            logerr("Data will not be uploaded")
-            return
-
-        site_dict['manager_dict'] = weewx.manager.get_manager_dict(
-            config_dict['DataBindings'], config_dict['Databases'], 'wx_binding')
         if config_dict['StdRESTful']['ThingSpeak'].has_key('fields'):
             site_dict['fields'] = dict(config_dict['StdRESTful']['ThingSpeak']['fields'])
         else:
             site_dict['fields'] = self._DEFAULT_FIELDS
 
+        site_dict['manager_dict'] = weewx.manager.get_manager_dict(
+            config_dict['DataBindings'],config_dict['Databases'],'wx_binding')
+
         self.archive_queue = Queue.Queue()
         self.archive_thread = ThingSpeakThread(self.archive_queue, **site_dict)
         self.archive_thread.start()
@@ -178,7 +171,7 @@ class ThingSpeakThread(weewx.restx.RESTThread):
     _DEFAULT_SERVER_URL = 'http://api.thingspeak.com/update'
 
     def __init__(self, queue, api_key, manager_dict,
-                 fields=None, unit_system=None,
+                 fields=None, unit_system=None, augment_record=True,
                  server_url=_DEFAULT_SERVER_URL, skip_upload=False,
                  post_interval=None, max_backlog=sys.maxint, stale=None,
                  log_success=True, log_failure=True,
@@ -198,10 +191,12 @@ class ThingSpeakThread(weewx.restx.RESTThread):
         self.server_url = server_url
         self.fields = fields
         self.unit_system = unit_system
+        self.augment_record = augment_record
         self.skip_upload = to_bool(skip_upload)
 
     def process_record(self, record, dbm):
-        record = self.get_record(record, dbm)
+        if self.augment_record:
+            record = self.get_record(record, dbm)
         if self.unit_system is not None:
             record = weewx.units.to_std_system(record, self.unit_system)
         url = self.get_url(record)
